#!/bin/sh
#
# ConfigScripts - install.sh
# Written by Alexander Barton <alex@barton.de>. Public Domain.
#

NAME=`basename "$0"`

Msg() {
	printf -- "$*"
}

Abort() {
	Msg "- ERROR!\n"
	exit 1
}

Copy_File() {
	src="$1"; dst="$2"; own="$3"; perm="$4"
	Msg "     $src -> $dst"
	if [ -e "$dst" ]; then
		grep "alex@barton.de" "$dst" >/dev/null 2>&1
		if [ $? -ne 0 ]; then
			Msg " (B)"
			cp "$dst" "$dst.bak"
		fi
	fi
	Msg " "
	cp "$src" "$dst" || Abort
	[ -n "$own" ] && chown "$own" "$dst" || Abort
	[ -n "$perm" ] && chmod "$perm" "$dst" || Abort
	Msg "- OK.\n"
}

Config_System() {
	if [ "$UID" = "0" ]; then
		Msg "Starting system configuration:\n"
		Msg " - bash shell:\n"
		if [ -e /etc/bash.bashrc ]; then
			Copy_File sys/bashrc /etc/bash.bashrc root 644
		else
			Copy_File sys/bashrc /etc/bashrc root 644
		fi
		Copy_File sys/profile /etc/profile root 644
	else
		Msg "Not running with root privileges - system configuration SKIPPED.\n"
		grep "alex@barton.de" /etc/profile >/dev/null 2>&1
		if [ $? -ne 0 ]; then
			Msg "Installing system files to $HOME/.etc/ ...\n"
			mkdir -p "$HOME/.etc"
			Copy_File sys/bashrc $HOME/.etc/bashrc "$user" 600
			Copy_File sys/profile $HOME/.etc/profile "$user" 600
		else
			Msg "System configuration seems to be modified: not installing locally.\n"
		fi
	fi
}

Config_User() {
	# $1: user name
	# $2: home directory

	user="$1"
	home="$2"

	Msg "Starting user configuration ($user in $home):\n"
	touch "$home/.test.$$" >/dev/null 2>&1
	if [ $? -eq 0 ]; then
		rm -f "$home/.test.$$"
		Msg " - bash shell:\n"
		if [ -e "$home/.profile" ]; then
			Copy_File user/bash_profile "$home/.profile" "$user" 600
		else
			Copy_File user/bash_profile "$home/.bash_profile" "$user" 600
		fi
		Copy_File user/bashrc "$home/.bashrc" "$user" 600
		Copy_File user/bash_logout "$home/.bash_logout" "$user" 600
	else
		Msg "Can't write to user home directory - user configuration SKIPPED.\n"
	fi
}

Config_RootUser() {
	if [ "$UID" = "0" ]; then
		user=`grep "^.*:.*:0:" /etc/passwd | head -n 1 | cut -d':' -f1`
		home=`grep "^.*:.*:0:" /etc/passwd | cut -d':' -f6`
		Config_User "$user" "$home"
	else
		Msg "Not running with root privileges - root user configuration SKIPPED.\n"
	fi
}

[ -n "$UID" ] || UID=`id -u`
export UID

Msg "Running $NAME (uid=$UID) ...\n"

user=`basename "$HOME"`

Config_System
Config_User "$user" "$HOME"
Config_RootUser

Msg "$NAME: Done.\n"

# -eof-
